import javabook.*;

/**
 * Questa classe controlla tutti gli oggetti coinvolti nella
 * realizzazione del gioco HiLo.
 *
 */
class HiLo
{

  //--------------------------------
  //  Attributi
  //--------------------------------

  private final int        MAX_TENTATIVI       = 6;

  private MainWindow       mainWindow;
  private MessageBox       messageBox;
  private OutputBox        outputBox;
  private ResponseBox      responseBox;
  private InputBox         inputBox;

  private int              numeroSegreto;

  //--------------------------------
  //  Costruttori
  //--------------------------------

  /**
   * Costruttore di default. Il titolo della finestra principale
   *  impostato a "Giochiamo ad HiLo!"
   */
  public HiLo( )
  {
    mainWindow    = new MainWindow  ("Giochiamo ad HiLo!");
    outputBox     = new OutputBox   ( mainWindow );
    responseBox   = new ResponseBox ( mainWindow );
    messageBox    = new MessageBox  ( mainWindow );
    inputBox      = new InputBox    ( mainWindow );

    mainWindow.setVisible( true );
    outputBox.setVisible( true );
  }

  //-------------------------------------------------
  //    Metodi pubblici:
  //
  //      void    start    (    )
  //
  //------------------------------------------------

  /**
   * Il metodo di pi alto livello che richiama tutti gli altri
   * metodi privati che consentono di giocare la partita.
   */
  public void start ( )
  {
    int risposta;

    mostraRegole();

    risposta = responseBox.prompt("Vuoi giocare ad HiLo?");

    while ( risposta == ResponseBox.YES ) {

      generaNumeroSegreto( );

      gioca();

      risposta = responseBox.prompt("Vuoi giocare ancora?");
    }
  }

  //-------------------------------------------------
  //    Metodi privati:
  //
  //    void    mostraRegole           (      )
  //    void    generaNumeroSegreto    (      )
  //    void    gioca                  (      )
  //
  //------------------------------------------------

  /**
   * Fornisce una breve spiegazione del gioco all'utente.
   *
   */
  private void mostraRegole( )
  {
    outputBox.skipLine(1);
    outputBox.printLine("L'obiettivo del gioco   quello di indovinare");
    outputBox.printLine("un numero segreto (un intero tra 1 e 100)");
    outputBox.printLine("con il minor numero di tentativi. Il massimo");
    outputBox.printLine("numero di tentativi consentito  sei. Il programma");
    outputBox.printLine("visualizza HI se la stima  pi alta del numero");
    outputBox.printLine("e LO se la stima  pi bassa del numero.");

    outputBox.skipLine(1);
    outputBox.printLine("Chiudere la finestra di descrizione per continuare.");

    outputBox.waitUntilClose( );
  }

  /**
   * Genera un numero pseudo-casuale tra 1 and 100.
   *
   */
  private void generaNumeroSegreto( )
  {
    double X = Math.random();
    numeroSegreto = (int) Math.floor( X * 100 ) + 1;
  }


  /**
   * Gioca ad HiLo.
   *
   */
  private void gioca( )
  {
    int NumeroTentativi = 0;
    int tentativo;

    do {
      // prossimo tentativo
      tentativo = richiediNumero();

      NumeroTentativi++;

      // controlla il tentativo
      if (tentativo < numeroSegreto) {
        messageBox.show("Il tuo tentativo  LO");
      } else if (tentativo > numeroSegreto) {
        messageBox.show("Il tuo tentativo  HI");
      }

    } while ( NumeroTentativi < MAX_TENTATIVI &&
              tentativo != numeroSegreto );

    // visualizza un messaggio appropriato
    if ( tentativo == numeroSegreto ) {
      messageBox.show("Hai indovinato in "
                      + NumeroTentativi  + " tentativi.");
    } else {
      messageBox.show("Hai perso. Il numero segreto era "
                      + numeroSegreto);
    }

  }

  /**
   * Richiede un numero all'utente
   */
  private int richiediNumero( )
  {
    int tentativo;

    tentativo = inputBox.getInteger("Inserisci un numero tra 1 e 100");

    while (tentativo < 1 || tentativo > 100) {
      messageBox.show("Il numero deve essere tra 1 e 100");
      tentativo = inputBox.getInteger("Inserisci un numero");
    }

    return tentativo;
  }
}